AchievementRepositoryImpl class

Inheritance

Constructors

AchievementRepositoryImpl([AchievementDatasource? achievementDatasource])

Properties

achievementDatasource → AchievementDatasource
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

getAchievement({required Map<String, dynamic> dateFilter, String? type, List<String>? tags, String? after, String? before, bool? offsetPaginated, num? page, num? limit, String? distinctId, String? goalId, String? order}) → Future<List<Achievements>>
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited