AuthMapper class
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
authActionResultToEntity(
AuthActionResultResponse response) → AuthActionResult -
loginFormToEntity(
LoginFormResponse response) → LoginForm -
loginToEntity(
LoginResponse login) → Login -
logoutToEntity(
LogoutResponse logout) → Logout -
participantLoginRequirementsToEntity(
ParticipantLoginRequirementsResponse response) → ParticipantLoginRequirements -
registerToEntity(
RegisterResponse register) → Register -
resetPasswordToEntity(
ResetPasswordResponse resetPassword) → ForgotPassword -
resetPassWordValidateToEntity(
ValidateChannelResponse resetPassWordValidate) → ForgotPassword -
setupTwoFactorTotpToEntity(
SetupTwoFactorTotpResponse response) → SetupTwoFactorTotp -
verifyEmailResendToEntity(
VerifyEmailResponse verifyEmailResend) → EmailVerify -
verifyEmailToEntity(
VerifyEmailResponse verifyEmail) → EmailVerify