BlogRepositoryImpl class
Methods
-
createBlog({required String title, required String body, required String format, required String category, required String distinctId, List<String>? tags, File? attachedFile, String? pushRedirectUrl})
→ Future<CreateBlog>
-
override
-
deleteBlog({required String distinctId, required String blogId})
→ Future<DeleteBlog>
-
override
-
getBlog({required String blogId})
→ Future<GetBlog>
-
override
-
getBlogs({String? distinctId, String? moderation, List<String>? tags, String? category, String? q, String? page, String? limit})
→ Future<GetBlogs>
-
override
-
noSuchMethod(Invocation invocation)
→ dynamic
-
Invoked when a nonexistent method or property is accessed.
inherited
-
toString()
→ String
-
A string representation of this object.
inherited
-
updateBlog({required String blogId, required String title, required String body, required String format, required String category, List<String>? tags, File? attachedFile})
→ Future<UpdateBlog>
-
override