ConditionGoals class

Constructors

ConditionGoals({required String metricId, required String metricName, required String conditionOperator, required int value, required String timeframe})
ConditionGoals.fromJson(Map<String, dynamic> json)
factory

Properties

conditionOperator ↔ String
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
metricId ↔ String
getter/setter pair
metricName ↔ String
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
timeframe ↔ String
getter/setter pair
value ↔ int
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited