CouponRedemption class
Constructors
- CouponRedemption({required String id, required String redeemId, required String prizeName, required String imageUrl, required int createdAt, required int updatedAt, required int points, required dynamic pointType, required String state, required bool isRedemptionCoupon, required String prizeDescription, required String code})
-
CouponRedemption.fromJson(Map<
String, dynamic> json) -
factory
Properties
- code ↔ String
-
getter/setter pair
- createdAt ↔ int
-
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
- id ↔ String
-
getter/setter pair
- imageUrl ↔ String
-
getter/setter pair
- isRedemptionCoupon ↔ bool
-
getter/setter pair
- points ↔ int
-
getter/setter pair
- pointType ↔ dynamic
-
getter/setter pair
- prizeDescription ↔ String
-
getter/setter pair
- prizeName ↔ String
-
getter/setter pair
- redeemId ↔ String
-
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- state ↔ String
-
getter/setter pair
- updatedAt ↔ int
-
getter/setter pair
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited