CreateActivityExternalResponse class

Constructors

CreateActivityExternalResponse({required String ok, required int points, required ParticipantPointsExternal participant, required String message})
CreateActivityExternalResponse.fromJson(Map<String, dynamic> json)
factory

Properties

hashCode → int
The hash code for this object.
no setterinherited
message ↔ String
getter/setter pair
ok ↔ String
getter/setter pair
participant ↔ ParticipantPointsExternal
getter/setter pair
points ↔ int
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited