DataStatus class

Constructors

DataStatus({required int page, required int pageSize, required int totalPages, required int totalData, required List<GoalStatus> goalStatuses})
DataStatus.fromJson(Map<String, dynamic> json)
factory

Properties

goalStatuses ↔ List<GoalStatus>
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
page ↔ int
getter/setter pair
pageSize ↔ int
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
totalData ↔ int
getter/setter pair
totalPages ↔ int
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited