DatumListMetrics class

Constructors

DatumListMetrics({required String id, required String name, required String description, required String coll, required String targetProperty, required String analysisType, required List<FilterListMetricsResponse> filter, required bool useGoals, required List goalsRelatedInfo, required String slug})
DatumListMetrics.fromJson(Map<String, dynamic> json)
factory

Properties

analysisType ↔ String
getter/setter pair
coll ↔ String
getter/setter pair
description ↔ String
getter/setter pair
filter ↔ List<FilterListMetricsResponse>
getter/setter pair
goalsRelatedInfo ↔ List
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
id ↔ String
getter/setter pair
name ↔ String
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
slug ↔ String
getter/setter pair
targetProperty ↔ String
getter/setter pair
useGoals ↔ bool
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited