DynamicFieldsData class

Constructors

DynamicFieldsData({required String id, required String externalAction, required int totalFields, required List<FieldEntityModel> fields})
DynamicFieldsData.fromJson(Map<String, dynamic> json)
factory

Properties

externalAction → String
final
fields → List<FieldEntityModel>
final
hashCode → int
The hash code for this object.
no setterinherited
id → String
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
totalFields → int
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited