EntriesActiviyResponse class

Constructors

EntriesActiviyResponse({required int activityCount, required String category, required DateTime createdAt, required String moderation, required num points, required String state, required String id, required String slug, required String name, required ParticipantDataEntries participant, required bool asForm, required EntryData data, EntryPrizeResponse? prize, String? redemptionState, String? source, bool gift = false, EntryRedemptionResponse? redemption})
EntriesActiviyResponse.fromJson(Map<String, dynamic> json)
factory

Properties

activityCount ↔ int
getter/setter pair
asForm ↔ bool
getter/setter pair
category ↔ String
getter/setter pair
createdAt ↔ DateTime
getter/setter pair
data ↔ EntryData
getter/setter pair
gift ↔ bool
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
id ↔ String
getter/setter pair
moderation ↔ String
getter/setter pair
name ↔ String
getter/setter pair
participant ↔ ParticipantDataEntries
getter/setter pair
points ↔ num
getter/setter pair
prize ↔ EntryPrizeResponse?
getter/setter pair
redemption ↔ EntryRedemptionResponse?
getter/setter pair
redemptionState ↔ String?
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
slug ↔ String
getter/setter pair
source ↔ String?
getter/setter pair
state ↔ String
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited