EntriesDatasourceImpl class
Properties
-
dio
→ Dio
-
final
-
hashCode
→ int
-
The hash code for this object.
no setterinherited
-
runtimeType
→ Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
getListEntries({String? token, String? category, String? moderation, String? type, String? atype, String? after, String? before, bool? offetPaginated, num? page, num? limit, String? distinctId, bool? hideUndo, required Map<String, dynamic> dateFilter, String? view, String? order})
→ Future<ListEntries>
-
override
-
noSuchMethod(Invocation invocation)
→ dynamic
-
Invoked when a nonexistent method or property is accessed.
inherited
-
toString()
→ String
-
A string representation of this object.
inherited