EntryRedemptionResponse class

Constructors

EntryRedemptionResponse({required String id, required DateTime createdAt, required num points, String? prizeName, String? code, String? state})
EntryRedemptionResponse.fromJson(Map<String, dynamic> json)
factory

Properties

code ↔ String?
getter/setter pair
createdAt ↔ DateTime
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
id ↔ String
getter/setter pair
points ↔ num
getter/setter pair
prizeName ↔ String?
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
state ↔ String?
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited