ExternalDatasourceImpl class

Inheritance

Constructors

ExternalDatasourceImpl()

Properties

dio → Dio
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

createActivityExternal({required String distinctId, required String event, String? category, required Map<String, dynamic> properties}) → Future<CreateActivityExternal>
override
fillupExternalForm({required String token, required String externalActionId, String? category, required Map<String, dynamic> externalForm}) → Future<ExternalFormActionResult>
Llena (crea) un external form a partir de una external action ya existente (ej. external_action_id obtenido de getExternalFormListByCategory).
override
getExternalFormField({required String token, required String externalActionId}) → Future<ExternalFormField>
override
getExternalFormInfo({required String token, required String externalFormId}) → Future<ExternalFormActivity>
override
getExternalFormList({required String token, int? skip, int? limit}) → Future<ExternalFormActivityList>
override
getExternalFormListByCategory({required String token, required String category, String? limit, String? page, bool? participantMatchRules}) → Future<List<ExternalFormList>>
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited
updateExternalForm({required String token, required String externalFormId, required Map<String, dynamic> externalForm}) → Future<ExternalFormActionResult>
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited