ExternalFormActivityListResponse class

Constructors

ExternalFormActivityListResponse({required String ok, required int totalData, required int page, required int pageSize, required int totalPages, required List<ExternalFormActivityModel> externalForms})
ExternalFormActivityListResponse.fromJson(Map<String, dynamic> json)
factory

Properties

externalForms ↔ List<ExternalFormActivityModel>
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
ok ↔ String
getter/setter pair
page ↔ int
getter/setter pair
pageSize ↔ int
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
totalData ↔ int
getter/setter pair
totalPages ↔ int
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited