ExternalMapper class
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
createActivityExternalToEntity(
CreateActivityExternalResponse response) → CreateActivityExternal -
externalFormActionResultToEntity(
ExternalFormActionResultResponse response) → ExternalFormActionResult -
externalFormActivityListToEntity(
ExternalFormActivityListResponse response) → ExternalFormActivityList -
externalFormFieldToEntity(
DynamicFieldsResponse response) → ExternalFormField -
externalFormInfoToEntity(
ExternalFormInfoResponse response) → ExternalFormActivity -
externalFormListToEntity(
External response) → ExternalFormList