FieldEntityModel class
Constructors
-
FieldEntityModel({required String fieldType, required String typeValue, required String name, required String label, String? helpText, String? placeholder, dynamic defaultValue, required bool requiredField, required bool uniqueField, String? format, List<
ChoiceEntity> ? choices, Map<String, dynamic> properties = const {}}) -
FieldEntityModel.fromJson(Map<
String, dynamic> json) -
factory
Properties
-
choices
→ List<
ChoiceEntity> ? -
final
- defaultValue → dynamic
-
final
- fieldType → String
-
final
- format → String?
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- helpText → String?
-
final
- label → String
-
final
- name → String
-
final
- placeholder → String?
-
final
-
properties
→ Map<
String, dynamic> -
final
- requiredField → bool
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- typeValue → String
-
final
- uniqueField → bool
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited