GoalDatasourceImpl class
Properties
-
dio
→ Dio
-
final
-
hashCode
→ int
-
The hash code for this object.
no setterinherited
-
runtimeType
→ Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
acceptGoals({required String goalId, required String distinctId, String? uidType})
→ Future<AcceptGoals>
-
override
-
getGoalsIndex({required bool enabled, required List<String> tags, num? page, num? limit, bool? trending, String? q})
→ Future<List<IndexGoals>>
-
override
-
getGoalsParticipant({required String token, required List<String> tags, required String distictId, int page = 1})
→ Future<List<GoalsParticipant>>
-
override
-
getGoalStatus({required String token, required String goalId})
→ Future<GoalStatusInfo>
-
override
-
noSuchMethod(Invocation invocation)
→ dynamic
-
Invoked when a nonexistent method or property is accessed.
inherited
-
toString()
→ String
-
A string representation of this object.
inherited
-
unacceptGoals({required String goalId, required String distinctId, String? uidType})
→ Future<UnacceptGoals>
-
override