GoalStatusInfoObject class
Constructors
-
GoalStatusInfoObject({required String name, required String status, required int winned, required List<
String> winningDates, required String goalId}) -
GoalStatusInfoObject.fromJson(Map<
String, dynamic> json) -
factory
Properties
- goalId ↔ String
-
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
- name ↔ String
-
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- status ↔ String
-
getter/setter pair
- winned ↔ int
-
getter/setter pair
-
winningDates
↔ List<
String> -
getter/setter pair
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited