LocalizationRepositoryImpl class
- Inheritance
-
- Object
- LocalizationRepository
- LocalizationRepositoryImpl
Constructors
- LocalizationRepositoryImpl([LocalizationDatasource? datasource])
Properties
- datasource → LocalizationDatasource
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
getCRTiendas(
{required String plaza, String q = '', String limit = '10'}) → Future< CrTienda> -
override
-
getRegions(
{required String region}) → Future< Region> -
override
-
getZonas(
{required String zona}) → Future< Zona> -
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited