LoginFormFieldModel class

Constructors

LoginFormFieldModel({required String type, required String fieldType, required String name, required String label, required bool requiredField, required bool uniqueField, Map<String, dynamic> properties = const {}})
LoginFormFieldModel.fromJson(Map<String, dynamic> json)
factory

Properties

fieldType → String
final
hashCode → int
The hash code for this object.
no setterinherited
label → String
final
name → String
final
properties → Map<String, dynamic>
final
requiredField → bool
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
type → String
final
uniqueField → bool
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited