MetadataReward class

Constructors

MetadataReward({required String name, required String description, required String termsAndConditions, required String image, required bool localizable, required List cities, required PrizeDetails prizeDetails, required List extraFields})
MetadataReward.empty()
factory
MetadataReward.fromJson(Map<String, dynamic> json)
factory

Properties

cities ↔ List
getter/setter pair
description ↔ String
getter/setter pair
extraFields ↔ List
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
image ↔ String
getter/setter pair
localizable ↔ bool
getter/setter pair
name ↔ String
getter/setter pair
prizeDetails ↔ PrizeDetails
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
termsAndConditions ↔ String
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited