Object class

Solo estos campos son consistentes entre campaigns (mismo nombre, mismo significado); todo lo demás varía de forma y se guarda tal cual en properties. Ver el comentario en la entidad de dominio para ver ejemplos reales de cuánto varía el resto del payload.

Constructors

Object({required String uid, required dynamic uidType, required String email, required num points, required num totalPoints, required List coins, required List totalCoins, required String state, required bool badEmail, required bool emailVerified, required bool cellphoneVerified, required bool unconfirmedEmail, required bool unconfirmedCellphone, required String avatar, required DateTime lastActivityAt, required List<String> tags, Map<String, dynamic> properties = const {}})
Object.fromJson(Map<String, dynamic> json)
factory

Properties

avatar ↔ String
getter/setter pair
badEmail ↔ bool
getter/setter pair
cellphoneVerified ↔ bool
getter/setter pair
coins ↔ List
getter/setter pair
email ↔ String
getter/setter pair
emailVerified ↔ bool
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
lastActivityAt ↔ DateTime
getter/setter pair
points ↔ num
getter/setter pair
properties ↔ Map<String, dynamic>
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
state ↔ String
getter/setter pair
tags ↔ List<String>
getter/setter pair
totalCoins ↔ List
getter/setter pair
totalPoints ↔ num
getter/setter pair
uid ↔ String
getter/setter pair
uidType ↔ dynamic
getter/setter pair
unconfirmedCellphone ↔ bool
getter/setter pair
unconfirmedEmail ↔ bool
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited