ParticipantCheck class

Constructors

ParticipantCheck({required int missingPoints, required dynamic missingLevel, required dynamic missingBadges, required dynamic missingRule, required bool userOverlimit, required bool canRedeem, required String message})
ParticipantCheck.fromJson(Map<String, dynamic> json)
factory

Properties

canRedeem ↔ bool
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
message ↔ String
getter/setter pair
missingBadges ↔ dynamic
getter/setter pair
missingLevel ↔ dynamic
getter/setter pair
missingPoints ↔ int
getter/setter pair
missingRule ↔ dynamic
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
userOverlimit ↔ bool
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited