ParticipantMapper class
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
participantListToEntity(
ParticipantListResponse response) → List< Participant> -
participantPointsToEntity(
ParticipantPointsResponse response) → ParticipantPoints -
participantPublicInfoToEntity(
ParticipantPublicInfoResponse response) → ParticipantPublicInfo -
participantRankToEntity(
ParticipantRankingResponse response) → AdvancedRanking -
redeemPointsToEntity(
RedeemPointsResponse response) → RedeemPoints -
toEntity(
Participant participant) → Participant -
updateAvatarToEntity(
UpdateParticipantAvatarResponse response) → UpdateAvatar -
updateUserToEntity(
UpdateParticipantResponse response) → UpdateUser