ParticipantPointsObject class
Constructors
- ParticipantPointsObject({required num totalPoints, required num points, required num redeemedPoints, required num pointsToExpire, required String expirationDate, required num expiredPoints})
-
ParticipantPointsObject.fromJson(Map<
String, dynamic> json) -
factory
Properties
- expirationDate ↔ String
-
getter/setter pair
- expiredPoints ↔ num
-
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
- points ↔ num
-
getter/setter pair
- pointsToExpire ↔ num
-
getter/setter pair
- redeemedPoints ↔ num
-
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- totalPoints ↔ num
-
getter/setter pair
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited