ParticipantRepositoryImpl class

Inheritance

Constructors

ParticipantRepositoryImpl([ParticipantDatasource? datasource])

Properties

datasource → ParticipantDatasource
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

getParticipantPoints({required String token}) → Future<ParticipantPoints>
override
getParticipantPublicInfo({required String token}) → Future<ParticipantPublicInfo>
override
getParticipantRanking({required String apiKey, required String campaign, required String distinctId}) → Future<AdvancedRanking>
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
redeemPoints({required String token, required num points}) → Future<RedeemPoints>
override
searchParticipants({required String token, List<String>? tags}) → Future<List<Participant>>
Busca participantes por tags (uso típico: admin/coordinador buscando participantes asociados).
override
toString() → String
A string representation of this object.
inherited
updateAvatar({required String token, required String distinctId, required String url}) → Future<UpdateAvatar>
override
updateUser({required String token, required String distinctId, String? name, String? phone, String? cargo, String? fcmToken, String? autorizationNumber}) → Future<UpdateUser>
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited