PointsInPeriodObject class

Constructors

PointsInPeriodObject({required DateTime startDate, required DateTime endDate, String? pointTypeId, required num points})
PointsInPeriodObject.fromJson(Map<String, dynamic> json)
factory

Properties

endDate ↔ DateTime
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
points ↔ num
getter/setter pair
pointTypeId ↔ String?
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
startDate ↔ DateTime
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited