Prize class

Constructors

Prize({required String type, required String name, required String description, required int points, required bool isRedeemable, required bool isAvailable, required bool requireExtraForm})
Prize.fromJson(Map<String, dynamic> json)
factory

Properties

description ↔ String
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
isAvailable ↔ bool
getter/setter pair
isRedeemable ↔ bool
getter/setter pair
name ↔ String
getter/setter pair
points ↔ int
getter/setter pair
requireExtraForm ↔ bool
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
type ↔ String
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited