PrizeDatasourceImpl class
Properties
-
dio
→ Dio
-
final
-
hashCode
→ int
-
The hash code for this object.
no setterinherited
-
runtimeType
→ Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
checkRedeemReward({required String distinctId, required String rewardId})
→ Future<RewardCheck>
-
override
-
getPrizes({num? page, num? limit, List<String>? tags, bool? redeemable, bool? fitsPoints, String? distinctId, Map<String, dynamic>? sort})
→ Future<List<Reward>>
-
override
-
noSuchMethod(Invocation invocation)
→ dynamic
-
Invoked when a nonexistent method or property is accessed.
inherited
-
rewardRedeem({required String distinctId, required String rewardId, Map<String, dynamic>? formData, String? category})
→ Future<RewardRedeem>
-
override
-
toString()
→ String
-
A string representation of this object.
inherited