PrizeRepositoryImpl class

Inheritance

Constructors

PrizeRepositoryImpl([PrizesDatasource? datasource])

Properties

datasource → PrizesDatasource
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

checkRedeemReward({required String distinctId, required String rewardId}) → Future<RewardCheck>
override
getCouponInfo({required String code}) → Future<CouponInfo>
Consulta el estado de un cupón ya redimido a partir de su code.
override
getPrizes({num? page, num? limit, List<String>? tags, bool? redeemable, bool? fitsPoints, String? distinctId, Map<String, dynamic>? sort}) → Future<List<Reward>>
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
redeemCoupon({required String couponId, required String distinctId}) → Future<CouponRedeemResult>
Genera (redime) un cupón para el premio couponId, devolviendo el código de canje en CouponRedeemResult.code.
override
rewardRedeem({required String distinctId, required String rewardId, Map<String, dynamic>? formData, String? category}) → Future<RewardRedeem>
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited