RedeemedPrizeRepositoryImpl class
- Inheritance
-
- Object
- RedeemedPrizeRepository
- RedeemedPrizeRepositoryImpl
Constructors
- RedeemedPrizeRepositoryImpl([RedeemedPrizeDatasource? datasource])
Properties
- datasource → RedeemedPrizeDatasource
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
getRedeemedPrizesByCategory(
{required String category}) → Future< List< RedeemedPrize> > -
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited