RedeemedPrizesResponse class

Constructors

RedeemedPrizesResponse({required bool ok, required String category, required int total, required List<RedeemedPrizeData> data})
RedeemedPrizesResponse.fromJson(Map<String, dynamic> json)
factory

Properties

category ↔ String
getter/setter pair
data ↔ List<RedeemedPrizeData>
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
ok ↔ bool
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
total ↔ int
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited