ReferralDatasourceImpl class

Inheritance

Constructors

ReferralDatasourceImpl()

Properties

dio → Dio
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

getOrUpdateReferralCode({required String token, String? code}) → Future<ReferralCode>
Sin code consulta el código de referido actual del participante; con code lo actualiza.
override
getParticipantReferrals({required String token, int? page, int? limit}) → Future<ParticipantReferrals>
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited