RewardResponse class
Constructors
-
RewardResponse({required String ok, required int page, required int pageSize, required int totalPages, required int totalData, required List<
ObjectReward> object}) -
RewardResponse.fromJson(Map<
String, dynamic> json) -
factory
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
-
object
↔ List<
ObjectReward> -
getter/setter pair
- ok ↔ String
-
getter/setter pair
- page ↔ int
-
getter/setter pair
- pageSize ↔ int
-
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- totalData ↔ int
-
getter/setter pair
- totalPages ↔ int
-
getter/setter pair
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited