TiendaResponse class

Constructors

TiendaResponse({required String plaza, required String q, required int total, required int count, required int? nextCursor, required List<Item> items})
TiendaResponse.fromJson(Map<String, dynamic> json)
factory

Properties

count ↔ int
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
items ↔ List<Item>
getter/setter pair
nextCursor ↔ int?
getter/setter pair
plaza ↔ String
getter/setter pair
q ↔ String
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
total ↔ int
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited