UpdateBlogParticipant class

Constructors

UpdateBlogParticipant({required String id, required String email, required String name, required String avatar, required String uid, required String uidType, required String state})
UpdateBlogParticipant.fromJson(Map<String, dynamic> json)
factory

Properties

avatar ↔ String
getter/setter pair
email ↔ String
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
id ↔ String
getter/setter pair
name ↔ String
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
state ↔ String
getter/setter pair
uid ↔ String
getter/setter pair
uidType ↔ String
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited