UpdateBlogResponse class
Constructors
- UpdateBlogResponse({required String ok, required String activityState, required int activityPoints, required String message, required String executionError, required UpdateBlogObject object})
-
UpdateBlogResponse.fromJson(Map<
String, dynamic> json) -
factory
Properties
- activityPoints ↔ int
-
getter/setter pair
- activityState ↔ String
-
getter/setter pair
- executionError ↔ String
-
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
- message ↔ String
-
getter/setter pair
- object ↔ UpdateBlogObject
-
getter/setter pair
- ok ↔ String
-
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited