UploadPhotoRepositoryImpl class

Inheritance

Constructors

UploadPhotoRepositoryImpl([UploadPhotoDatasource? datasource])

Properties

datasource → UploadPhotoDatasource
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited
uploadPhoto({required String distinctId, required File photo, String? imageName}) → Future<UploadPhoto>
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited