BlogDatasource class abstract

Implementers

Constructors

BlogDatasource()

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

createBlog({required String title, required String body, required String format, required String category, required String distinctId, List<String>? tags, File? attachedFile, String? pushRedirectUrl}) → Future<CreateBlog>
deleteBlog({required String distinctId, required String blogId}) → Future<DeleteBlog>
getBlog({required String blogId}) → Future<GetBlog>
getBlogs({String? distinctId, String? moderation, List<String>? tags, String? category, String? q, String? page, String? limit}) → Future<GetBlogs>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited
updateBlog({required String blogId, required String title, required String body, required String format, required String category, List<String>? tags, File? attachedFile}) → Future<UpdateBlog>

Operators

operator ==(Object other) → bool
The equality operator.
inherited