CommentDatasourceImpl class
- Inheritance
-
- Object
- CommentDatasource
- CommentDatasourceImpl
Constructors
Properties
- dio → Dio
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
createComment(
{required String token, required String targetId, required String body, String? category, List< String> ? tags, String? pushRedirectUrl}) → Future<CommentActivityResult> -
override
-
deleteComment(
{required String token, required String distinctId, required String targetId, required String commentId}) → Future< DeleteComment> -
override
-
listComments(
{required String token, required String targetId}) → Future< ListComments> -
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
-
updateComment(
{required String token, required String targetId, required String commentId, required String body, String? category, List< String> ? tags, String? pushRedirectUrl}) → Future<CommentActivityResult> -
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited