CustomData class
Constructors
- CustomData({required String nombre, required String apellidoPaterno, required String apellidoMaterno, required String correo, required String telefono, required String calle, required String noExt, required String noInt, required String colonia, required String municipio, required String estado, required String cp, required String referencia, required String entreCalles})
-
CustomData.fromJson(Map<
String, dynamic> json) -
factory
Properties
- apellidoMaterno ↔ String
-
getter/setter pair
- apellidoPaterno ↔ String
-
getter/setter pair
- calle ↔ String
-
getter/setter pair
- colonia ↔ String
-
getter/setter pair
- correo ↔ String
-
getter/setter pair
- cp ↔ String
-
getter/setter pair
- entreCalles ↔ String
-
getter/setter pair
- estado ↔ String
-
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
- municipio ↔ String
-
getter/setter pair
- noExt ↔ String
-
getter/setter pair
- noInt ↔ String
-
getter/setter pair
- nombre ↔ String
-
getter/setter pair
- referencia ↔ String
-
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- telefono ↔ String
-
getter/setter pair
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited