ExternalFormActivityModel class
Constructors
-
ExternalFormActivityModel({required String id, required String type, required int activityCount, required String atype, String? category, required String moderation, required num points, required String state, required int createdAt, required int executeDate, required String module, required String name, required dynamic team, required Participant participant, Map<
String, dynamic> properties = const {}}) -
ExternalFormActivityModel.fromJson(Map<
String, dynamic> json) -
factory
Properties
- activityCount ↔ int
-
getter/setter pair
- atype ↔ String
-
getter/setter pair
- category ↔ String?
-
getter/setter pair
- createdAt ↔ int
-
getter/setter pair
- executeDate ↔ int
-
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
- id ↔ String
-
getter/setter pair
- moderation ↔ String
-
getter/setter pair
- module ↔ String
-
getter/setter pair
- name ↔ String
-
getter/setter pair
- participant ↔ Participant
-
getter/setter pair
- points ↔ num
-
getter/setter pair
-
properties
↔ Map<
String, dynamic> -
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- state ↔ String
-
getter/setter pair
- team ↔ dynamic
-
getter/setter pair
- type ↔ String
-
getter/setter pair
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited