MetricsDatasourceImpl class
- Inheritance
-
- Object
- MetricsDatasource
- MetricsDatasourceImpl
Constructors
Properties
- dio → Dio
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
calculateMetrics(
{required String distinctId, required String slug, required String timeFrame, String? uidType}) → Future< CalculateMetrics> -
override
-
getMetrics(
{num? limit, num? page, String? q}) → Future< ListMetrics> -
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited