ParticipantPointsExternal class
Constructors
- ParticipantPointsExternal({required int accumulatedPoints, required int availablePoints, required int redeemedPoints, required int pointsToExpire, required String expirationDate, required int expiredPoints})
-
ParticipantPointsExternal.fromJson(Map<
String, dynamic> json) -
factory
Properties
- accumulatedPoints ↔ int
-
getter/setter pair
- availablePoints ↔ int
-
getter/setter pair
- expirationDate ↔ String
-
getter/setter pair
- expiredPoints ↔ int
-
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
- pointsToExpire ↔ int
-
getter/setter pair
- redeemedPoints ↔ int
-
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited