RankingDatasourceImpl class
Properties
-
dio
→ Dio
-
final
-
hashCode
→ int
-
The hash code for this object.
no setterinherited
-
runtimeType
→ Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
getAvancedRangking({required String distinctId, List<String>? categories, bool? exactCategories, String? sector, String? sectorB, String? sectorC, String? activityType, String? pointType, num? startingPoints, num? limitPoints, num? rankingSize, num? page, num? perPage, bool? includeLoggedParticipant})
→ Future<List<AdvancedRanking>>
-
override
-
getPointsInPeriod({required String distinctId, required String startDate, required String endDate})
→ Future<PointsInPeriod>
-
Puntos ganados por un participante en un rango de fechas.
override
-
getRankingSegment({List<String>? categories, String? pointType})
→ Future<List<RankingSegment>>
-
Ranking agrupado por segmento (combinación de tags de participante),
en vez de un ranking individual por participante.
override
-
noSuchMethod(Invocation invocation)
→ dynamic
-
Invoked when a nonexistent method or property is accessed.
inherited
-
toString()
→ String
-
A string representation of this object.
inherited