VotesDatasourceImpl class

Inheritance

Constructors

VotesDatasourceImpl()

Properties

dio → Dio
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

countVotesPublication({String? distinctId, required String targetId}) → Future<CountVotesPublication>
override
createVote({required String distinctId, required String targetId, required String category, bool? toggle}) → Future<CreateVote>
override
deleteVote({required String distinctId, required String targetId}) → Future<DeleteVote>
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited
updateVote({required String distinctId, required String targetId, required String category}) → Future<UpdateVote>
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited