Password class
Password validated against a configurable set of rules. Every rule is opt-in via the constructor and defaults match the previous fixed behaviour (min. 5 chars, at least one uppercase and one special char).
- Inheritance
-
- Object
- FormzInput<
String, PasswordError> - Password
Constructors
- Password.dirty(String value, {int minLength = 5, bool requireUppercase = true, bool requireLowercase = false, bool requireNumber = false, bool requireSpecialChar = true})
-
const
- Password.pure({int minLength = 5, bool requireUppercase = true, bool requireLowercase = false, bool requireNumber = false, bool requireSpecialChar = true})
-
const
Properties
- displayError → PasswordError?
-
The error to display if the
FormzInputvalue is not valid and has been modified.no setterinherited - error → PasswordError?
-
Returns a validation error if the
FormzInputis invalid. Returnsnullif theFormzInputis valid.no setterinherited - errorMessage → String?
-
no setter
- hashCode → int
-
The hash code for this object.
no setterinherited
- isNotValid → bool
-
Whether the
FormzInputvalue is not valid. A value is invalid when the overriddenvalidatorreturns an error (non-null value).no setterinherited - isPure → bool
-
If the
FormzInputis pure (has been touched/modified). Typically when theFormzInputis initially created, it is created using theFormzInput.pureconstructor to signify that the user has not modified it.finalinherited - isValid → bool
-
Whether the
FormzInputvalue is valid according to the overriddenvalidator.no setterinherited - minLength → int
-
final
- requireLowercase → bool
-
final
- requireNumber → bool
-
final
- requireSpecialChar → bool
-
final
- requireUppercase → bool
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- value → String
-
The value of the given
FormzInput. For example, if you have aFormzInputforFirstName, the value could be 'Joe'.finalinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
-
validator(
String value) → PasswordError? -
A function that must return a validation error if the provided
valueis invalid andnullotherwise.override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited